==> kubernetes-model-apps-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/apps/RollingUpdateStatefulSetStrategyFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RollingUpdateStatefulSetStrategyFluent<A extends RollingUpdateStatefulSetStrategyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable();
  public IntOrString buildMaxUnavailable();
  public A withMaxUnavailable(IntOrString maxUnavailable);
  public Boolean hasMaxUnavailable();
  public A withNewMaxUnavailable(Object value);
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item);
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> editMaxUnavailable();
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable();
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item);
  public Integer getPartition();
  public A withPartition(Integer partition);
  public Boolean hasPartition();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MaxUnavailableNested<N> extends Nested<N>,IntOrStringFluent<RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<N>>{
    public N and();
    public N endMaxUnavailable();
    
  }
  
}

==> kubernetes-model-apps-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apps/RollingUpdateStatefulSetStrategyFluent.java <==
package io.fabric8.kubernetes.api.model.apps;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RollingUpdateStatefulSetStrategyFluent<A extends RollingUpdateStatefulSetStrategyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable();
  public IntOrString buildMaxUnavailable();
  public A withMaxUnavailable(IntOrString maxUnavailable);
  public Boolean hasMaxUnavailable();
  public A withNewMaxUnavailable(Object value);
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item);
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> editMaxUnavailable();
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable();
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item);
  public Integer getPartition();
  public A withPartition(Integer partition);
  public Boolean hasPartition();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MaxUnavailableNested<N> extends Nested<N>,IntOrStringFluent<RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<N>>{
    public N and();
    public N endMaxUnavailable();
    
  }
  
}
